@@ -1,4 +1,4 @@
-# Copyright (c) 2009-2010 LOGILAB S.A. (Paris, FRANCE).
+# Copyright (c) 2009-2011 LOGILAB S.A. (Paris, FRANCE).
 # http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This program is free software; you can redistribute it and/or modify it under
@@ -20,6 +20,7 @@ import sys
 import mx.DateTime as dt
 import re
 import os, os.path as osp
+from itertools import chain
 
 from mercurial.node import nullrev
 from mercurial.node import hex, short as short_hex
@@ -176,6 +177,9 @@ class HgRepoListModel(QtCore.QAbstractTableModel):
         self.wd_status = [self.repo.status(ctx.node(), None)[:4] for ctx in wdctxs]
         self._user_colors = {}
         self._branch_colors = {}
+        # precompute named branch color for stable value.
+        for branch_name in chain(['default', 'stable'], sorted(repo.branchtags().keys())):
+            self.namedbranch_color(branch_name)
         grapher = revision_grapher(self.repo, start_rev=fromhead,
                                    follow=follow, branch=branch)
         self.graph = Graph(self.repo, grapher, self.max_file_size)
@@ -251,7 +255,7 @@ class HgRepoListModel(QtCore.QAbstractTableModel):
         self.fill_step = cfg.getFillingStep()
         self.max_file_size = cfg.getMaxFileSize()
         self.hide_mq_tags = cfg.getMQHideTags()
-        
+
         cols = getattr(cfg, self._getcolumns)()
         if cols is not None:
             validcols = [col for col in cols if col in self._allcolumns]
